import { navigationActions } from 'src/actions';
import { routeList } from 'src/routeList';
import { JolocomLib } from 'jolocom-lib';
import { Linking } from 'react-native';
import { cancelSSO } from 'src/actions/sso';
import { AppError, ErrorCode } from 'src/lib/errors';
import { keyIdToDid } from 'jolocom-lib/js/utils/helper';
import { generateIdentitySummary } from './utils';
import fetch from 'node-fetch';
export const consumePaymentRequest = (paymentRequest, isDeepLinkInteraction = false) => async (dispatch, getState, backendMiddleware) => {
    const { identityWallet, registry } = backendMiddleware;
    await identityWallet.validateJWT(paymentRequest, undefined, registry);
    const requester = await registry.resolve(keyIdToDid(paymentRequest.issuer));
    const requesterSummary = generateIdentitySummary(requester);
    const paymentDetails = {
        receiver: {
            did: paymentRequest.issuer,
            address: paymentRequest.interactionToken.transactionOptions.to,
        },
        requester: requesterSummary,
        callbackURL: paymentRequest.interactionToken.callbackURL,
        amount: paymentRequest.interactionToken.transactionOptions.value,
        description: paymentRequest.interactionToken.description,
        requestJWT: paymentRequest.encode(),
    };
    return dispatch(navigationActions.navigate({
        routeName: routeList.PaymentConsent,
        params: { isDeepLinkInteraction, paymentDetails },
        key: 'paymentRequest',
    }));
};
export const sendPaymentResponse = (isDeepLinkInteraction, paymentDetails) => async (dispatch, getState, backendMiddleware) => {
    const { identityWallet } = backendMiddleware;
    const { callbackURL, requestJWT } = paymentDetails;
    // add loading screen here
    const password = await backendMiddleware.keyChainLib.getPassword();
    const decodedPaymentRequest = JolocomLib.parse.interactionToken.fromJWT(requestJWT);
    const txHash = await identityWallet.transactions.sendTransaction(decodedPaymentRequest.interactionToken, password);
    const response = await identityWallet.create.interactionTokens.response.payment({ txHash }, password, decodedPaymentRequest);
    if (isDeepLinkInteraction) {
        const callback = `${callbackURL}/${response.encode()}`;
        if (!(await Linking.canOpenURL(callback))) {
            throw new AppError(ErrorCode.DeepLinkUrlNotFound);
        }
        return Linking.openURL(callback).then(() => dispatch(cancelSSO));
    }
    else {
        return fetch(callbackURL, {
            method: 'POST',
            body: JSON.stringify({ token: response.encode() }),
            headers: { 'Content-Type': 'application/json' },
        }).then(() => dispatch(cancelSSO));
    }
};
