import { buildTransform } from './filter';
import { complement } from 'ramda';
const expiredFilter = cred => cred.expires ? cred.expires.valueOf() < new Date().valueOf() : true;
const validFilter = complement(expiredFilter);
const issuerFilter = (issuerDid) => cred => cred.issuer.did === issuerDid;
const typeFilter = (typ) => cred => cred.credentialType.includes(typ);
/**
 * @dev Some basic predefined filters, if required they can be removed
 * and the filtering / ordering construction functions can be exposed instead
 */
export const filters = {
    filterByExpired: buildTransform([expiredFilter]),
    filterByValid: buildTransform([validFilter]),
    filterByIssuer: (did) => buildTransform([issuerFilter(did)]),
    filterByType: (typ) => buildTransform([typeFilter(typ)]),
    documentFilter: (documentTypes) => buildTransform(documentTypes.map(typeFilter)),
};
