import RNFetchBlob from 'rn-fetch-blob';
import FormData from 'form-data';
export class IpfsCustomConnector {
    constructor(config) {
        this.nativeLib = RNFetchBlob;
        this.ipfsHost = `${config.protocol}://${config.host}:${config.port}`;
    }
    async storeJSON({ data, pin, }) {
        if (!data || typeof data !== 'object') {
            throw new Error(`JSON expected, received ${typeof data}`);
        }
        // TODO: clarify if we need formData
        // const formData = new FormData()
        // formData.append('file', Buffer.from(JSON.stringify(data)))
        const endpoint = `${this.ipfsHost}/api/v0/add?pin=${pin}`;
        const headers = { 'Content-Type': 'multipart/form-data' };
        const res = await this.nativeLib.fetch('POST', endpoint, headers, [
            {
                name: 'ddo',
                data: JSON.stringify(data),
            },
        ]);
        return res.json().Hash;
    }
    async catJSON(hash) {
        const endpoint = `${this.ipfsHost}/api/v0/cat?arg=${hash}`;
        const res = await this.nativeLib.fetch('GET', endpoint);
        return res.json();
    }
    async removePinnedHash(hash) {
        const resolutionGateway = 'https://ipfs.io/ipfs/';
        const endpoint = `${resolutionGateway}/${hash}`;
        const res = await this.nativeLib.fetch('GET', endpoint);
        if (res.respInfo.status !== 200) {
            throw new Error(`Removing pinned hash ${hash} failed, status code: ${res.respInfo.status}`);
        }
    }
    async createDagObject({ data, pin, }) {
        if (!data || typeof data !== 'object') {
            throw new Error(`Object expected, received ${typeof data}`);
        }
        const formData = new FormData();
        formData.append('file', Buffer.from(JSON.stringify(data)));
        const endpoint = `${this.ipfsHost}/api/v0/dag/put?pin=${pin}`;
        const headers = { 'Content-Type': 'multipart/form-data' };
        const res = this.nativeLib.fetch('POST', endpoint, headers, [
            {
                name: 'dag',
                data: formData,
            },
        ]);
        return (await res).json().Cid['/'];
    }
    async resolveIpldPath(pathToResolve) {
        const endpoint = `${this.ipfsHost}/api/v0/dag/get?arg=${pathToResolve}`;
        const res = this.nativeLib.fetch('GET', endpoint);
        return (await res).json();
    }
}
