import { HAS_EXTERNAL_CREDENTIALS } from '../../actions/account/actionTypes';
const categorizedClaims = {
    Personal: [
        {
            credentialType: 'Name',
            claimData: {
                givenName: '',
                familyName: '',
            },
            id: '',
            issuer: {
                did: '',
            },
            subject: '',
        },
    ],
    Contact: [
        {
            credentialType: 'Email',
            claimData: {
                email: '',
            },
            id: '',
            issuer: {
                did: '',
            },
            subject: '',
            keyboardType: 'email-address',
        },
        {
            credentialType: 'Mobile Phone',
            claimData: {
                telephone: '',
            },
            id: '',
            issuer: {
                did: '',
            },
            subject: '',
            keyboardType: 'phone-pad',
        },
        {
            credentialType: 'Postal Address',
            claimData: {
                addressLine1: '',
                addressLine2: '',
                postalCode: '',
                city: '',
                country: '',
            },
            id: '',
            issuer: {
                did: '',
            },
            subject: '',
        },
    ],
    // /** @dev FOR TESTING */
    Other: [],
};
export const initialState = {
    selected: {
        credentialType: '',
        claimData: {},
        id: '',
        issuer: {
            did: '',
        },
        subject: '',
    },
    pendingExternal: {
        offeror: {
            did: '',
        },
        offer: [],
    },
    decoratedCredentials: categorizedClaims,
    hasExternalCredentials: false,
};
export const claims = (state = initialState, action) => {
    switch (action.type) {
        case 'SET_CLAIMS_FOR_DID':
            return Object.assign({}, state, { decoratedCredentials: addDefaultValues(action.claims) });
        case HAS_EXTERNAL_CREDENTIALS:
            return Object.assign({}, state, { hasExternalCredentials: action.value });
        case 'SET_EXTERNAL':
            return Object.assign({}, state, { pendingExternal: action.value });
        case 'RESET_EXTERNAL':
            return Object.assign({}, state, { pendingExternal: initialState.pendingExternal }); // TODO Remove in favor of calling set external with empty array
        case 'SET_SELECTED':
            return Object.assign({}, state, { selected: action.selected });
        case 'RESET_SELECTED':
            return Object.assign({}, state, { selected: initialState.selected });
        case 'HANDLE_CLAIM_INPUT':
            // NOTE: this is handled slightly differently so that we prevent the
            // claimData keys from being re-ordered, as they are used to generate the
            // fields in ui/home/components/claimDetails
            const claimData = Object.assign({}, state.selected.claimData);
            claimData[action.fieldName] = action.fieldValue;
            return Object.assign({}, state, { selected: Object.assign({}, state.selected, { claimData }) });
        default:
            return state;
    }
};
const addDefaultValues = (claims) => Object.keys(categorizedClaims).reduce((acc, category) => (Object.assign({}, acc, { [category]: injectPlaceholdersIfNeeded(category, claims[category]) })), {});
const injectPlaceholdersIfNeeded = (category, claims) => {
    if (!claims || claims.length === 0) {
        return categorizedClaims[category];
    }
    const missing = categorizedClaims[category].filter(defaultClaim => !claims.some(claim => claim.credentialType === defaultClaim.credentialType));
    if (missing) {
        return [...missing, ...claims];
    }
    return claims;
};
