import { navigationActions } from 'src/actions/';
import { routeList } from 'src/routeList';
import SplashScreen from 'react-native-splash-screen';
import { AppError, ErrorCode } from 'src/lib/errors';
export const showErrorScreen = (error) => dispatch => {
    const appError = error.constructor === AppError
        ? error
        : new AppError(ErrorCode.Unknown, error);
    return dispatch(navigationActions.navigate({
        routeName: routeList.Exception,
        params: {
            returnTo: appError.navigateTo,
            error: appError,
        },
    }));
};
export const initApp = async (dispatch, getState, backendMiddleware) => {
    try {
        await backendMiddleware.initStorage();
        const storedSettings = await backendMiddleware.storageLib.get.settingsObject();
        // locale setup
        // if (storedSettings.locale) I18n.locale = storedSettings.locale
        // else storedSettings.locale = I18n.locale
        SplashScreen.hide();
        return dispatch(loadSettings(storedSettings));
    }
    catch (e) {
        return dispatch(showErrorScreen(new AppError(ErrorCode.WalletInitFailed, e, routeList.Landing)));
    }
};
export const loadSettings = (settings) => ({
    type: 'LOAD_SETTINGS',
    value: settings,
});
