import { buildTransform } from './filter';
import { complement } from 'ramda';
const expiredFilter = cred => cred.expires.valueOf() < new Date().valueOf();
const validFilter = complement(expiredFilter);
const issuerFilter = (issuerDid) => cred => cred.issuer === issuerDid;
const typeFilter = (typ) => cred => cred.type.includes(typ);
const mostRecentOrder = (c1, c2) => c2.issued.valueOf() - c1.issued.valueOf();
/**
 * @dev Some basic predefined filters, if required they can be removed
 * and the filtering / ordering construction functions can be exposed instead
 */
export const filters = {
    filterByExpired: buildTransform([expiredFilter]),
    filterByValid: buildTransform([validFilter]),
    filterByIssuer: (did) => buildTransform([issuerFilter(did)]),
    filterByType: (typ) => buildTransform([typeFilter(typ)]),
    orderByRecent: buildTransform([mostRecentOrder]),
    documentFilter: (documentTypes) => buildTransform(documentTypes.map(typeFilter)),
};
