/**
 * This file contains polyfills for various things that are somehow coupled
 * with react-native. This is meant to be used as a polyfill for running the
 * backendMiddleware and redux store under node
 */
function logCall(pref) {
    return (msg) => console.log(`${pref}: ${msg}`);
}
import { BackendMiddleware } from 'src/backendMiddleware';
import { createStore, applyMiddleware } from 'redux';
import thunk from 'redux-thunk';
import { rootReducer } from 'src/reducers';
const ormconfig = require('../ormconfig.ts').default;
// change type to 'sqlite' instead of 'react-native'
ormconfig.type = 'sqlite';
ormconfig.database = 'db.sqlite3';
export function initStore() {
    const config = require('src/config.ts');
    config.typeOrmConfig = ormconfig;
    // instantiate the storage backend
    const backendMiddleware = new BackendMiddleware(config);
    const store = Object.assign({}, createStore(rootReducer, {}, applyMiddleware(thunk.withExtraArgument(backendMiddleware))), { backendMiddleware });
    return store;
}
import { writeFileSync, readFileSync } from 'fs';
import path from 'path';
// from src/lib/keychain.ts
export class KeyChain {
    constructor() {
        this.pass = null;
    }
    async getPassword() {
        if (this.pass != null)
            return this.pass;
        try {
            this.pass = readFileSync(KeyChain.PASSWORD_LOCATION).toString();
        }
        catch (err) {
            console.error('Error reading password file', err, '\n\n');
            throw err;
        }
        return this.pass;
    }
    async savePassword(pass) {
        console.log('KEYCHAIN SAVED PASSWORD: ', pass);
        this.pass = pass;
        writeFileSync(KeyChain.PASSWORD_LOCATION, pass);
    }
}
KeyChain.PASSWORD_LOCATION = path.resolve(`${__dirname}/../local_identity.password.txt`);
const fetch = require('node-fetch');
const FormData = require('form-data');
export { IpfsStorageAgent as IpfsCustomConnector, } from 'node_modules/jolocom-lib/js/ipfs/ipfs';
// default export merge of all default exports
export default {
    // RNFetchBlob default export
    // @ts-ignore
    fetch: function (method, endpoint, headers, formDataList) {
        console.log(arguments);
        const body = new FormData();
        formDataList.forEach((item) => {
            body.append(item.name, item.data);
        });
        return fetch(endpoint, { method, body, headers }).then((res) => {
            console.log('body', res.body.toString());
            return res;
        });
    },
    // src/locales/i18n.ts default export
    t: (str) => str,
    // react-native-splash-screen
    hide: () => logCall('SplashScreen')('hide'),
};
import { randomBytes } from 'crypto';
export const NativeModules = { RNRandomBytes: { randomBytes } };
export class Linking {
    static async canOpenURL(url) {
        console.log('canOpenURL called with ' + url);
        return true;
    }
    static async openURL(url) {
        console.log('openURL called with ' + url);
    }
}
export function initSentry() {
    console.log('initSentry');
}
export function reportErrorToSentry(err, extraData) {
    console.error('reportErrorToSentry:\n', err.error, extraData);
}
export function findBestAvailableLanguage(locales) {
    return {
        languageTag: 'en',
    };
}
